gmm method of findThresholdGmmThreshold contains output from the gmm method findThreshold.
It includes parameters of two Gaussian fits and threshold cut.
# S4 method for GmmThreshold
print(x)# S4 method for GmmThreshold,missing
plot(x, y, ...)
GmmThreshold object
ignored.
arguments to pass to plotGmmThreshold.
xinput distance vector with NA or infinite values removed.
modelfirst-second fit functions.
cutofftype of threshold cut.
a1mixing weight of the first curve.
b1second parameter of the first curve. Either the mean of a Normal distribution or shape of a Gamma distribution.
c1third parameter of the first curve. Either the standard deviation of a Normal distribution or scale of a Gamma distribution.
a2mixing weight of the second curve.
b2second parameter of the second curve. Either the mean of a Normal distribution or shape of a Gamma distribution.
c2third parameter of the second curve. Either the standard deviation of a Normal distribution or scale of a Gamma distribution.
loglklog-likelihood of the fit.
thresholdthreshold.
sensitivitysensitivity.
specificityspecificity.
pvaluep-value from Hartigans' dip statistic (HDS) test. Values less than 0.05 indicate significant bimodality.
findThreshold